@@ -1,6 +1,6 @@
 ##---------------------------------------------------------------------------##
 ##  File:
-##	$Id: mhrcfile.pl,v 2.21 2002/06/07 17:45:09 ehood Exp $
+##	$Id: mhrcfile.pl,v 2.24 2002/06/29 00:57:08 ehood Exp $
 ##  Author:
 ##      Earl Hood       mhonarc@mhonarc.org
 ##  Description:
@@ -149,13 +149,6 @@ sub read_resource_file {
 	    }
 	    last FMTSW;
 	}
-	if ($elem eq 'dbfile') {		# Database file
-	    if ($line = &get_elem_last_line($handle, $elem)) {
-		$line =~ s/\s//g;
-		$DBFILE = $line;
-	    }
-	    last FMTSW;
-	}
 	if ($elem eq 'excs') {			# Exclude header fields
 	    %HFieldsExc = ()  if $override;
 	    while (defined($line = <$handle>)) {
@@ -418,6 +411,16 @@ sub read_resource_file {
 	    }
 	    last FMTSW;
 	}
+	if ($elem eq 'mimealtprefs') {		# Mime alternative prefs
+	    $IsDefault{'MIMEALTPREFS'} = 0;
+	    @MIMEAltPrefs = ();
+	    while (defined($line = <$handle>)) {
+		last  if $line =~ /^\s*<\/mimealtprefs\s*>/i;
+		$line =~ s/\s//g;
+		push(@MIMEAltPrefs, lc($line))  if $line;
+	    }
+	    last FMTSW;
+	}
 	if ($elem eq 'mimedecoders') {		# Mime decoders
 	    $IsDefault{'MIMEDECODERS'} = 0;
 	    if ($override) {
@@ -766,6 +769,18 @@ sub read_resource_file {
 	    $SSMARKUP = &get_elem_content($handle, $elem, $chop);
 	    last FMTSW;
 	}
+	if ($elem eq 'msgpgssmarkup') {		# Initial message page markup
+	    $MSGPGSSMARKUP = &get_elem_content($handle, $elem, $chop);
+	    last FMTSW;
+	}
+	if ($elem eq 'idxpgssmarkup') {		# Initial index page markup
+	    $IDXPGSSMARKUP = &get_elem_content($handle, $elem, $chop);
+	    last FMTSW;
+	}
+	if ($elem eq 'tidxpgssmarkup') {	# Initial thread idx page markup
+	    $TIDXPGSSMARKUP = &get_elem_content($handle, $elem, $chop);
+	    last FMTSW;
+	}
 	if ($elem eq 'subjectarticlerxp') {	# Regex for language articles
 	    if ($line = &get_elem_last_line($handle, $elem)) {
 		$SubArtRxp = $line;
